<?php

namespace ProgrammaBill\Commands;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface,
    Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Output\OutputInterface;
use Webmozart\Assert\Assert;
use ProgrammaBill\Messages\BulkUpdate;
use ProgrammaBill\MessageHandlers\BulkUpdateHandler;
use ProgrammaBill\Entities\InvoiceAction;

class BulkPlatformInvoicesPaid extends Command {

    protected static $defaultName = 'app:run-bulk-platform-invoice-paid';
    protected static $defaultDescription = 'Run a bulk update of platform invoices and mark them all as paid.';

    private $bulkUpdateHandler;

    public function __construct(BulkUpdateHandler $bulkUpdateHandler) {
        $this->bulkUpdateHandler = $bulkUpdateHandler;
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int {
        $bulkUpdate = new BulkUpdate(
            (int)$input->getArgument('marketplace'),
            BulkUpdate::IDS_ALL_MARKETPLACE_NUMBER,
            $input->getArgument('numbers'),
            InvoiceAction::TYPE_PAYIN,
            [ 'source' => 'bulk_cli' ]
        );

        $this->bulkUpdateHandler->__invoke($bulkUpdate);

        return 0;
    }

    protected function configure(): void {
        $this->addArgument('marketplace', InputArgument::REQUIRED, 'Marketplace ID.');
        $this->addArgument('numbers', InputArgument::IS_ARRAY, 'Invoice numbers, separated by spaces.');
    }
}
