<?php

namespace ProgrammaBill\Commands;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface,
    Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Output\OutputInterface;
use Doctrine\ORM\EntityManagerInterface;
use ProgrammaBill\InvoiceFormatter;
use ProgrammaBill\Entities\Transaction;

class PreviewInvoiceHTML extends Command {

    protected static $defaultName = 'app-debug:preview-invoice-html';
    protected static $defaultDescription = 'Returns HTML for an invoice.';

    private $repository;
    private $formatter;

    public function __construct(EntityManagerInterface $entityManager, InvoiceFormatter $formatter) {
        $this->repository = $entityManager->getRepository(Transaction::class);
        $this->formatter = $formatter;
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int {
        $transaction = $this->repository->findOneById($input->getArgument('transaction'));
        if (!isset($transaction)) {
            $output->writeln('Transaction not found.');
            return 1;
        }

        $invoice = $transaction->getInvoiceWithNumber($input->getArgument('invoice'));
        if (!isset($invoice)) {
            $output->writeln('Invoice not found.');
            return 1;
        }

        $output->writeln($this->formatter->getHTML($invoice));

        return 0;
    }

    protected function configure(): void {
        $this->addArgument('transaction', InputArgument::REQUIRED, 'Transaction ID.');
        $this->addArgument('invoice', InputArgument::REQUIRED, 'Invoice Number.');
    }
}