<?php

namespace ProgrammaBill\Commands;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface,
    Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Output\OutputInterface;
use Doctrine\ORM\EntityManagerInterface;
use CloudObjects\SDK\ObjectRetriever;
use ProgrammaBill\InvoiceFormatter;
use ProgrammaBill\Entities\Marketplace;

class RebuildAllPDFs extends Command {

    protected static $defaultName = 'app:rebuild-all-pdfs';
    protected static $defaultDescription = 'Rebuilds all PDFs for a marketplace.';

    private $repository;
    private $formatter;
    private $retriever;

    public function __construct(EntityManagerInterface $entityManager, InvoiceFormatter $formatter,
            ObjectRetriever $retriever) {
        $this->repository = $entityManager->getRepository(Marketplace::class);
        $this->formatter = $formatter;
        $this->retriever = $retriever;
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int {
        $marketplace = $this->repository->fetchOrCreateWithNamespace($input->getArgument('domain'));
        $marketplace->setObjectRetriever($this->retriever);
        foreach ($marketplace->getTransactions() as $t) {
            foreach ($t->getInvoices() as $i) {
                $output->writeln($this->formatter->getSignedPDFURL($i));
                $this->formatter->createAndUploadPDF($i);                
            }
        }

        return 0;
    }

    protected function configure(): void {
        $this->addArgument('domain', InputArgument::REQUIRED, 'Marketplace domain.');
    }
}