<?php

namespace ProgrammaBill\Commands;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface,
    Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Output\OutputInterface;
use Carbon\Carbon;
use ProgrammaBill\Messages\BulkExport;
use ProgrammaBill\MessageHandlers\BulkExportHandler;

class TriggerBulkExport extends Command {

    protected static $defaultName = 'app:run-bulk-export';
    protected static $defaultDescription = 'Run a bulk export.';

    private $bulkExportHandler;

    public function __construct(BulkExportHandler $bulkExportHandler) {
        $this->bulkExportHandler = $bulkExportHandler;
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int {
        $bulkExport = new BulkExport(
            'ProgrammaBill\\Entities\\' . $input->getArgument('type'),
            (int)$input->getArgument('target'),
            Carbon::parse($input->getArgument('start')),
            Carbon::parse($input->getArgument('end')),
            []
        );

        $this->bulkExportHandler->__invoke($bulkExport);

        return 0;
    }

    protected function configure(): void {
        $this->addArgument('type', InputArgument::REQUIRED, 'Entity type.');
        $this->addArgument('target', InputArgument::REQUIRED, 'Entity ID.');
        $this->addArgument('start', InputArgument::REQUIRED, 'Start date/time.');
        $this->addArgument('end', InputArgument::REQUIRED, 'End date/time.');
    }
}
