<?php

namespace ProgrammaBill;

use Silex\Application;
use Silex\Provider\DoctrineServiceProvider;
use Dflydev\Silex\Provider\DoctrineOrm\DoctrineOrmServiceProvider;

class ConfigLoader {

	static function configure(Application $app, $config) {
		// Initialize Doctrine DBAL Service Provider
		$app->register(new DoctrineServiceProvider, array(
			"db.options" => array(
				"driver" => "pdo_mysql",
				"charset" => "UTF8",
				"driverOptions" => array(
					"charset" => "UTF8",
					1002 => "SET NAMES UTF8"
				),
				"dbname" => $config['db.name'],
				"port" => isset($config['db.port']) ? $config['db.port'] : 3306,
				"host" => $config['db.host'],
				"user" => $config['db.user'],
				"password" => $config['db.password']
			)
		));

		// Initialize Doctrine ORM Service Provider
		$app->register(new DoctrineOrmServiceProvider, array(
			"orm.proxies_dir" => __DIR__."/../../proxies",
			"orm.auto_generate_proxies" => false,
			"orm.em.options" => array(
				"mappings" => array(
					array(
						"type" => "annotation",
						"namespace" => "ProgrammaBill\Entities",
						"path" => __DIR__."/Entities",
					)
				),
				"metadata_cache" => $config['db.cache'],
				"query_cache" => $config['db.cache'],
				"result_cache" => $config['db.cache']
			)
		));

		// Initialize Twig
		$app['twig'] = $app->share(function() {
			$twig = new \Twig_Environment(
				new \Twig_Loader_Filesystem(__DIR__.'/../../templates'),
				array(
					'autoescape' => false,
					// 'cache' => __DIR__.'/../../cache'
				));
			$twig->getExtension('core')->setNumberFormat(2, ',', '');
			$twig->addExtension(new PunicTwig('de'));
			// TODO: add localization, this is German number format only at the moment
			return $twig;
		});

		// Get AWS credentials
		$app['aws.credentials'] = array(
			'key' => $config['aws.key'],
			'secret' => $config['aws.secret']
		);

		// Load and enable filter
		$app['orm.em.config']->addFilter("status", "ProgrammaBill\DatabaseStatusFilter");
		$app['orm.em']->getFilters()->enable('status');
	}

}
