<?php

namespace ProgrammaBill\Entities;

use DateTime;
use Doctrine\ORM\Mapping AS ORM;

/**
 * BaseEntity contains a few fields that are used in every database table.
 *
 * @ORM\MappedSuperclass
 */
abstract class BaseEntity {

	/** @ORM\Id @ORM\Column(type="integer", options={"unsigned":true}) @ORM\GeneratedValue **/
	private $id;

	/** @ORM\Column(type="smallint") **/
	private $status = 1;

	/** @ORM\Column(type="string", nullable=true, length=1) **/
	private $flag;

  	/** @ORM\Column(type="datetime", columnDefinition="DATETIME NOT NULL") **/
  	private $created_timestamp;

  	/** @ORM\Column(type="datetime", columnDefinition="TIMESTAMP NULL ON UPDATE CURRENT_TIMESTAMP") **/
  	private $modified_timestamp;

	public function __construct() {
		$this->created_timestamp = new DateTime;
	}

	/**
   	 * Get the sequential database identifier for this entity.
   	 * @return integer
   	 */
  	public function getId() {
    	return $this->id;
  	}

	/**
	 * Get the status of this entity.
	 * 1 = active
	 * 3 = marked for deletion
	 * @return integer
	 */
	public function getStatus() {
		return $this->status;
	}

	/**
	 * Set the status of this entity.
	 * 1 = active
	 * 3 = marked for deletion
	 * @param integer $status
	 * @return BaseEntity self-reference for chaining
	 */
	public function setStatus($status) {
		$this->status = $status;
		return $this;
	}

	/**
	 * Get the flag of this entity.
	 * @return char
	 */
	public function getFlag() {
		return $this->flag;
	}

	/**
	 * Set a flag for this entity.
	 * @param char $flag
	 * @return BaseEntity self-reference for chaining
	 */
	public function setFlag($flag) {
		$this->flag = $flag;
		return $this;
	}

	/**
	 * Get the timestamp on which this entity was first persisted in the database.
	 * @return DateTime
	 */
	public function getCreatedTimestamp() {
		return $this->created_timestamp;
	}

	/**
	 * Get the timestamp on which this entity was last edited in the database.
	 * @return DateTime
	 */
	public function getModifiedTimestamp() {
		return $this->modified_timestamp;
	}

}
