<?php

namespace ProgrammaBill\Entities;

use Exception;
use Doctrine\ORM\Mapping AS ORM;

/**
 * A RemoteService is a CloudObjects service which is integrated with a marketplace.
 *
 * @ORM\Entity(repositoryClass="ProgrammaBill\Repositories\RemoteServiceRepository")
 * @ORM\Table(name="mi_remote_services")
 */
class RemoteService extends BaseEntity {

    /** @ORM\Column(type="string", length=50, unique=true) **/
    private $service_domain;

    private $coid;
    private $objectRetriever;
    private $object;
    private $reader;

    private function getReader() {
        if (!isset($this->reader))
            $this->reader = new NodeReader([
                'prefixes' => [
                    'mi' => 'coid://marketplace-invoicing.cloudobjects.io/'
                ]
            ]);
    
        return $this->reader;
    }

    /**
     * Creates a new service.
     * @param string $service_domain CloudObjects service namespace
     */
    public function __construct(string $service_domain) {
        parent::__construct();
        $this->service_domain = $service_domain;
    }

    /**
     * Get the CloudObjects service namespace for this service.
     * @return string
     */
    public function getServiceDomain() {
        return $this->service_domain;
    }

    /**
     * Get the CloudObjects object representing the service.
     */
    public function getObject() {
        if (!isset($this->objectRetriever))
            throw new Exception("Must assign ObjectRetriever before retrieving object.");

        if (!isset($this->object))
            $this->object = $this->objectRetriever->getObject($this->getCOID());

        return $this->object;
    }

    /**
     * Get the COID for the remote service.
     */
    public function getCOID() {
        if (!isset($this->coid))
            $this->coid = new IRI('coid://'.$this->getServiceDomain());

        return $this->coid;
    }

}
