<?php

namespace ProgrammaBill\Integrations;

use Doctrine\ORM\EntityManagerInterface;
use Webmozart\Assert\Assert;
use GuzzleHttp\Client;
use ProgrammaBill\InvoiceFormatter;
use ProgrammaBill\Entities\RemoteService, ProgrammaBill\Entities\InvoiceLink,
    ProgrammaBill\Entities\Invoice, ProgrammaBill\Entities\Actor;

abstract class AbstractBookkeepingIntegration {

    private $entityManager;
    private $formatter;
    private $client;
    private $remoteService;

    public function __construct(EntityManagerInterface $entityManager, InvoiceFormatter $formatter) {
        $this->entityManager = $entityManager;
        $this->formatter = $formatter;
        $this->client = new Client;
    }

    protected function setRemoteService(RemoteService $remoteService) {
        $this->remoteService = $remoteService;
    }

    protected function getInvoiceFileURL(Invoice $invoice) {
        return $this->formatter->getSignedPDFURL($invoice);
    }

    protected function getInvoiceContents(Invoice $invoice) {
        return $this->client
            ->get($this->getInvoiceFileURL($invoice))
            ->getBody();
    }

    /**
     * Add an invoice to the remote service.
     * 
     * @param InvoiceLink $link Pre-created link that will be updated with ID and meta, if available
     * @return bool TRUE if added successfully, FALSE otherwise
     */
    abstract protected function addInvoiceToService(InvoiceLink $link);

    public function syncInvoice(Invoice $invoice, Actor $actor = null) {
        Assert::notNull($this->remoteService, "Must call setRemoveService() before attempting to sync an Invoice.");
        Assert::true($actor == null || $invoice->involvesActor($actor), "Invalid Actor for Invoice.");

        $existingLinks = $invoice->getLinks()->filter(function($link) use ($actor) {
            return ($link->getService() == $this->remoteService && $link->getActor() == $actor);
        });

        if (count($existingLinks) == 0) {
            // Create a new link
            $link = new InvoiceLink($invoice, $this->remoteService, $actor);
            $result = $this->addInvoiceToService($link);
            if ($result == true && $link->getExternalDocumentID() !== null) {
                // If we have an external ID, assume adding was successful; store in DB
                $invoice->getLinks()->add($link);
                $this->entityManager->persist($link);
                $this->entityManager->flush();
            }

            return $result;
        } else {
            // TODO: implement updating

            return false;
        }
    }
}