<?php

namespace ProgrammaBill\Interfaces;

use ProgrammaBill\Entities\Actor;

interface APIObject {

  /**
   * Updates this object with information from an API request.
   *
   * @param Actor $actor Actor on whose behalf the API request was made.
   * @param array $data The decoded JSON content of the API request.
   * @param array $options Optional parameters with instructions for processing the request.
   */
  public function parseAPIRequest(Actor $actor, array $data, array $options = []);

  /**
   * Checks whether the given data would be a valid API request for this object.
   *
   * @param array $data The decoded JSON content of the API request.
   * @return boolean
   */
  public static function isValidAPIRequest(array $data, array $options = []);

  /**
   * Serializes this object into an API response.
   *
   * @param Actor $actor Actor on whose behalf the API request was made.
   * @param array $options Optional parameters with instructions for processing the response.
   * @return array
   */
  public function createAPIResponse(Actor $actor = null, array $options = []);

  /*
  public function parseAPIRequest(Actor $actor, array $data, array $options = []);
  public static function isValidAPIRequest(array $data, array $options = []);
  public function createAPIResponse(Actor $actor, array $options = []);
  */
}
