<?php

namespace ProgrammaBill\Interfaces;

use Carbon\Carbon;

interface Address {

    /**
     * Get the country as an ISO-3166-1 code.
     * 
     * @return string|null
     */
    public function getCountry();

    /**
     * Generate a due date for an invoice.
     * 
     * @param Carbon $creationDate The date on which the invoice was created.
     * @return Carbon
     */
    public function getDueDateFromCreationDate(Carbon $creationDate);

    /**
     * Indicates whether this address belongs to a business or not.
     * 
     * @return bool
     */
    public function isBusiness();

    /**
     * Indicates whether the actor is located in the European Union.
     * 
     * @return bool
     */
    public function isLocatedInEU() : bool;

    /**
     * Indicates whether this actor is exempt from charging VAT.
     * 
     * @return bool
     */ 
    public function isVATExempt();

}