<?php

namespace ProgrammaBill\MessageHandlers;

use Exception;
use Symfony\Component\Messenger\Handler\MessageHandlerInterface;
use Doctrine\ORM\EntityManagerInterface;
use Webmozart\Assert\Assert;
use ProgrammaBill\Messages\BulkUpdate;
use ProgrammaBill\Entities\Marketplace,
    ProgrammaBill\Entities\Invoice,
    ProgrammaBill\Entities\InvoiceAction;

class BulkUpdateHandler implements MessageHandlerInterface {

    private $em;

    public function __construct(EntityManagerInterface $em) {
        $this->em = $em;
    }

    public function __invoke(BulkUpdate $update) {
        // Find invoices
        $invoices = [];

        switch ($update->getIdType()) {
            case BulkUpdate::IDS_ALL_MARKETPLACE_NUMBER:
                // We only deal with platform invoices from a marketplace
                $marketplace = $this->em->getRepository(Marketplace::class)
                    ->findOneById($update->getMarketplaceId());
                Assert::notNull($marketplace);
                $invoiceRepository = $this->em->getRepository(Invoice::class);
                foreach ($update->getInvoiceIds() as $id) {
                    try {
                        $invoice = $invoiceRepository->getPlatformInvoiceWithNumber($marketplace, $id);
                        if (isset($invoice)) {
                            $invoices[] = $invoice;
                        }
                    } catch (Exception $e) {
                        // TODO: update using logger instead of "echo"
                        echo $id . " - " . $e->getMessage()."\n";
                    }
                }
                break;
            default:
                throw new Exception("Unsupported ID type.");
        }

        // Update invoices
        foreach ($invoices as $i) {
            try {
                $action = new InvoiceAction($i, $update->getAction(), $update->getMeta());            
                $action->updateInvoiceStatus();
                $i->getActions()->add($action);
            } catch (Exception $e) {
                // TODO: update using logger instead of "echo"
                echo $e->getMessage()."\n";
            }            
        }

        $this->em->flush();
    }
}