<?php

namespace ProgrammaBill\Messages;

use DateTime;
use Webmozart\Assert\Assert;
use ProgrammaBill\Entities\Marketplace,
    ProgrammaBill\Entities\Actor;

/**
 * Triggers a bulk export of invoices,
 * either for a marketplace or an actor.
 */
class BulkExport {

    private $target_type;
    private $target_id;
    private $start_date;
    private $end_date;
    private $options;
    
    /**
     * @param string $target_type Either Marketplace or Actor class
     * @param int $target_id ID of the target for export
     * @param DateTime $start_date Start date for export
     * @param DateTime $end_date End date for export
     * @param array $options Other optional options
     */
    public function __construct(string $target_type, int $target_id,
            DateTime $start_date, DateTime $end_date, array $options) {
        
        Assert::oneOf($target_type, [ Marketplace::class, Actor::class ]);
        $this->target_type = $target_type;
        $this->target_id = $target_id;
        $this->start_date = $start_date;
        $this->end_date = $end_date;
        $this->options = $options;        
    }

    public function getTargetType() {
        return $this->target_type;
    }

    public function getTargetID() {
        return $this->target_id;
    }

    public function getOptions() {
        return $this->options;
    }

    public function getStartDate() {
        return $this->start_date;
    }

    public function getEndDate() {
        return $this->end_date;
    }

}