<?php

namespace ProgrammaBill\Messages;

use Webmozart\Assert\Assert;
use ProgrammaBill\Entities\InvoiceAction;

/**
 * Triggers a bulk update of invoices.
 */
class BulkUpdate {

    const IDS_ALL_MARKETPLACE_NUMBER = 1;

    private $marketplace_id;
    private $id_type;
    private $invoice_ids;
    private $action;
    private $meta;
    
    /**
     * @param int $marketplace_id ID of the marketplace.
     * @param int $id_type Invoice ID type.
     * @param array $invoice_ids List of invoice IDs following the ID type.
     * @param int $action An action to perform on all the invoices.
     * @param array $meta Meta data to add to the action.
     */
    public function __construct(int $marketplace_id, int $id_type, array $invoice_ids,
            int $action, array $meta) {
        
        Assert::oneOf($id_type, [ self::IDS_ALL_MARKETPLACE_NUMBER ]);
        Assert::oneOf($action, InvoiceAction::allTypes());
        $this->marketplace_id = $marketplace_id;
        $this->id_type = $id_type;
        $this->invoice_ids = $invoice_ids;
        $this->action = $action;
        $this->meta = $meta;
    }

    public function getMarketplaceId() {
        return $this->marketplace_id;
    }

    public function getIdType() {
        return $this->id_type;
    }

    public function getInvoiceIds() {
        return $this->invoice_ids;
    }

    public function getAction() {
        return $this->action;
    }

    public function getMeta() {
        return $this->meta;
    }

}