<?php

namespace ProgrammaBill;

use Exception;
use Punic\Territory;
use Punic\Calendar;
use Punic\Unit;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

class PunicTwig extends AbstractExtension {

  private $locale;

  public function setLocale($locale) {
    $this->locale = $locale;
  }

  public function getName() {
    return "punic";
  }

  public function getFilters() {
    return array(
      new TwigFilter('territoryName', function($string, $locale = null) {
        return Territory::getName($string, isset($locale) ? $locale : $this->locale);
      }),
      new TwigFilter('formatDateEx', function($date, $width) {
        return Calendar::formatDateEx($date, $width, '', $this->locale);
      }),
      new TwigFilter('unitName', function($string) {
        return Unit::getName($string, $this->locale);
      }),
      new TwigFilter('unitNameSingular', function($string, $locale = null) {
        if (!isset($locale)) $locale = $this->locale;
        try {
          return trim(str_replace('1', '', Unit::format(1, $string, $width = 'long', $locale)));
        } catch (Exception $e) {
          // if unit doesn't exist, return raw string
          return $string;
        }
      }),      
    );
  }

}
