<?php

namespace ProgrammaBill\Repositories;

use Doctrine\ORM\EntityRepository, Doctrine\ORM\NoResultException;
use ML\IRI\IRI;
use Webmozart\Assert\Assert;
use CloudObjects\SDK\COIDParser, CloudObjects\SDK\ObjectRetriever;
use ProgrammaBill\Entities\PaymentInstruction;

class PaymentInstructionRepository extends EntityRepository {

    private $retriever;

    public function setObjectRetriever(ObjectRetriever $retriever) {
        $this->retriever = $retriever;
        return $this;
    }

	public function getWithCOIDString($coidString) {
        if (substr($coidString, 0, 3) == 'mi:')
            $coidString = 'coid://marketplace-invoicing.cloudobjects.io/'.substr($coidString, 3);

        $coid = COIDParser::fromString($coidString);
        Assert::oneOf(COIDParser::getType($coid), [ COIDParser::COID_VERSIONED, COIDParser::COID_UNVERSIONED ], 'Payment instructions types must be COIDs.');

        $piObject = $this->retriever->getObject($coid);
        Assert::notNull($piObject, 'The specified payment instruction type does not exist.');
        $revision = $piObject->getProperty(ObjectRetriever::REVISION_PROPERTY)->getValue();

        $types = $piObject->getType();
        if (!is_array($types)) $types = [ $types ];
        $isPaymentInstruction = false;
        foreach ($types as $t)
            if ($t->getId() == 'coid://marketplace-invoicing.cloudobjects.io/PaymentInstructionType')
                $isPaymentInstruction = true;
        Assert::true($isPaymentInstruction, 'The object with COID <'.$coidString.'> is not a payment instruction type.');

		try {
			$query = $this->_em->createQuery('SELECT pi FROM ProgrammaBill\Entities\PaymentInstruction pi WHERE pi.coid = :coid AND pi.revision = :revision');
            $query->setParameter('coid', (string)$coid);
            $query->setParameter('revision', $revision);

			return $query->getSingleResult();
		} catch (NoResultException $e) {
		    $pi = new PaymentInstruction((string)$coid, $revision);
			$this->_em->persist($pi);
            
            return $pi;
        }
    }
}
