<?php

namespace ProgrammaBill\Repositories;

use Doctrine\ORM\EntityRepository;
use ProgrammaBill\FilterQuerySet;
use ProgrammaBill\Entities\Marketplace, ProgrammaBill\Entities\Transaction;

class TransactionRepository extends EntityRepository {
	
	/**
	 * Get all or query transactions for a marketplace.
	 * @param Marketplace $marketplace The marketplace.
	 */
	public function getAllForMarketplace(Marketplace $marketplace, FilterQuerySet $filterQuerySet = null) {
		$qb = $this->_em->createQueryBuilder()
			->select('t')
			->from(Transaction::class, 't')
			->where('t.marketplace = :marketplace')
			->setParameter('marketplace', $marketplace)
			->orderBy('t.id', 'desc');

		if (isset($filterQuerySet))
			$filterQuerySet->apply($qb, 't');

		return $qb->getQuery()->getResult();
	}

}
