<?php

namespace ProgrammaBill\Services;

use ML\IRI\IRI;
use Webmozart\Assert\Assert;
use CloudObjects\SDK\WebAPI\APIClientFactory;
use ProgrammaBill\Entities\Marketplace,
    ProgrammaBill\Entities\Actor;

class ActorCreator {

    private $agwAccountsApi;

    public function __construct(APIClientFactory $apiClientFactory) {
        $apiCoid = new IRI('coid://ac-do-fra1-alpha.cloudobjects.net/RemoteControl');
        $this->agwAccountsApi = $apiClientFactory->getClientWithCOID($apiCoid);
    }

    private function createActorForMarketplace(Marketplace $marketplace, array $accountTriples, array $personTriples) {
        $accountsApiResponse = json_decode($this->agwAccountsApi->post('/accounts', [
            'json' => [
                '@graph' => [
                    array_merge([
                        '@id' => 'aauid:self',
                        'coid://aauid.net/belongsToTenant' => [
                            '@id' => 'coid://'.$marketplace->getServiceDomain()
                        ]
                    ], $accountTriples),
                    array_merge([
                        '@id' => 'aauid:self:person'                        
                    ], $personTriples)
                ]
            ],
            'headers' => [
                'Content-Type' => 'application/ld+json'
            ]
        ])->getBody(), true);

        Assert::keyExists($accountsApiResponse, 'aauid');
        Assert::keyExists($accountsApiResponse, 'access_token');

        $actor = new Actor($marketplace, $accountsApiResponse['aauid'], Actor::TYPE_UNKNOWN);
        $actor->setAccessToken($accountsApiResponse['access_token']);
        return $actor;
    }

    public function createActorForMarketplaceWithEMail(Marketplace $marketplace, string $email) {
        Assert::email($email);

        $actor = $this->createActorForMarketplace($marketplace, [], [
            'http://xmlns.com/foaf/0.1/mbox_sha1sum' => sha1('mailto:'.$email)
        ]);
        $actor->setEmail($email);

        return $actor;
    }

    public function createActorForMarketplaceWithExternalUserID(Marketplace $marketplace, string $ext_user_id) {
        $actor = $this->createActorForMarketplace($marketplace, [
            'http://xmlns.com/foaf/0.1/accountName' => $ext_user_id
        ], []);
        $actor->setExternalUserID($ext_user_id);

        return $actor;
    }
}