<?php

namespace ProgrammaBill\UserAPI;

use DateTime;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request,
    Symfony\Component\HttpFoundation\Response;
use ProgrammaBill\AuthenticationSubscriber;
use ProgrammaBill\Entities\Invoice;

/**
 * @Route("/userapi")
 */
class Reports extends AbstractController {

    private $as;

    public function __construct(AuthenticationSubscriber $authenticationSubscriber) {
        $this->as = $authenticationSubscriber;
    }

    /**
     * @Route("/reports/merchant-total", methods="GET")
     */
    public function getMerchantTotal(Request $r) {
        $startDate = new DateTime($r->query->get('start_date'));
        $endDate = new DateTime($r->query->get('end_date'));
        $invoiceEvent = $r->query->get('event');

        $invoices = $this->getDoctrine()->getRepository(Invoice::class)
            ->getInvoicesForMerchant($this->as->getActor(),
                $invoiceEvent, $startDate, $endDate);
        
        $byCountry = [];
        $byEuVatId = [];
        foreach ($invoices as $i) {
            $country = $i->getTransaction()->getCustomer()->getCountry();
            $currency = $i->getCurrency();

            if (!isset($byCountry[$country]))
                $byCountry[$country] = [];
            if (!isset($byCountry[$country][$currency]))
                $byCountry[$country][$currency] = [
                    'total' => [
                        'pretax' => 0,
                        'tax' => 0,
                        'payable' => 0
                    ]
                ];
            
            foreach ($i->getTaxRates() as $tr) {
                $id = ($tr === 'R') ? 'reverse_charged' : 'tax_rate_'.$tr;

                if (!isset($byCountry[$country][$currency][$id]))
                    $byCountry[$country][$currency][$id] = [
                        'pretax' => 0,
                        'tax' => 0,
                        'payable' => 0
                    ];
                
                $byCountry[$country][$currency][$id]['pretax']
                    += $i->getPretaxAmountForRate($tr);
                $byCountry[$country][$currency][$id]['tax']
                    += $i->getTaxAmountAtRate($tr);
                $byCountry[$country][$currency][$id]['payable']
                    += $i->getPayableAmountForRate($tr);

                if ($tr === 'R') {
                    $vatId = $i->getTransaction()->getCustomer()->getEUVatId();
                    if (!isset($byEuVatId[$vatId]))
                        $byEuVatId[$vatId] = [];
                    if (!isset($byEuVatId[$vatId][$currency]))
                        $byEuVatId[$vatId][$currency] = 0;
                    
                    $byEuVatId[$vatId][$currency] += $i->getPretaxAmountForRate($tr);
                }
            }

            $byCountry[$country][$currency]['total']['pretax'] += $i->getTotalPretaxAmount();
            $byCountry[$country][$currency]['total']['tax'] += $i->getTotalTaxAmount();
            $byCountry[$country][$currency]['total']['payable'] += $i->getTotalPayableAmount();
        }

        return $this->json([
            'start_date' => $startDate->format('Y-m-d'),
            'end_date' => $endDate->format('Y-m-d'),
            'invoice_event' => $invoiceEvent,
            'invoice_count' => count($invoices),
            'total_by_country' => $byCountry,
            'total_reverse_charged_by_eu_vat_id' => $byEuVatId
        ]);
    }

}
