<?php

namespace ProgrammaBill\UserAPI;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request,
    Symfony\Component\HttpFoundation\Response;
use ProgrammaBill\AuthenticationSubscriber,
    ProgrammaBill\InvoiceFormatter;
use ProgrammaBill\Entities\Transaction;

/**
 * @Route("/userapi")
 */
class Transactions extends AbstractController {

    private $as;
    private $formatter;

    public function __construct(AuthenticationSubscriber $authenticationSubscriber, InvoiceFormatter $formatter) {
        $this->as = $authenticationSubscriber;
        $this->formatter = $formatter;
    }

    private function fetchTransaction($id) {
        // Fetch from database
        $transaction = $this->getDoctrine()->getRepository(Transaction::class)
            ->findOneById($id);

        // Check whether entity exists and assert access rights
        if (!isset($transaction) || ($transaction->getMerchant() != $this->as->getActor()
                && $transaction->getCustomer() != $this->as->getActor()))
            throw $this->createNotFoundException();

        return $transaction;
    }

    /**
     * @Route("/customer-transactions", methods="GET")
     */
    public function getAllForCustomer() {
        $items = [];
        foreach ($this->as->getActor()->getTransactionsAsCustomer() as $t) {
            $items[] = $t->createAPIResponse($this->as->getActor(), [
                'expand_linked_transactions' => false,
                '_invoice_formatter' => $this->formatter
            ]);
        }

        return $this->json([
            'items' => $items
        ]);
    }

    /**
     * @Route("/merchant-transactions", methods="GET")
     */
    public function getAllForMerchant() {
        $items = [];
        foreach ($this->as->getActor()->getTransactionsAsMerchant() as $t) {
            $items[] = $t->createAPIResponse($this->as->getActor(), [
                'expand_linked_transactions' => false,
                '_invoice_formatter' => $this->formatter
            ]);
        }

        return $this->json([
            'items' => $items
        ]);
    }

    /**
     * @Route("/transactions/{id}", methods="GET")
     */
    public function getOne($id) {
        // Fetch transaction
        $transaction = $this->fetchTransaction($id);

        // Generate response
        return $this->json($transaction->createAPIResponse($this->as->getActor(), [
            'expand_linked_transactions' => true,
            '_invoice_formatter' => $this->formatter
        ]));
    }

}
